Tests — django-evade 0.1 documentation

# Tests

Continuous integration test results are available online.

However, you can also test the source code.

    $ workon myvenv
    $ django-admin.py test evade.tests --settings="evade.tests.settings"

    Creating test database for alias 'default'...
    ..........
    ----------------------------------------------------------------------
    Ran 10 tests in 0.260s

    OK
    Destroying test database for alias 'default'...

A bundled settings file allows you to test the code without even creating a Django project.